@@ -1,6 +1,6 @@
 from matplotlib import pyplot as plt
 import math
-from keras.callbacks import LambdaCallback, EarlyStopping, ModelCheckpoint
+from keras.callbacks import LambdaCallback, EarlyStopping, ModelCheckpoint, models
 import keras.backend as K
 import numpy as np
 import pandas as pd 
@@ -37,9 +37,14 @@ class sanity_check:
     steps_per_epochs = len(train_generator)
     
     for x in self.loss_record.keys():
+      K.clear_session()
       print('learning_Rate : ',x)
       self.cur_rate = float(x)
-      K.set_value(self.model.optimizer.lr, self.cur_rate)
+      
+      mod = models.clone_model(self.model)
+      
+    
+      K.set_value(self.model.optimizer.lr, x)
 
       batchcallback = LambdaCallback(on_batch_end=lambda batch,
                                                       logs: self.on_batch_end(batch, logs))
@@ -62,7 +67,7 @@ class sanity_check:
       lr_df = pd.DataFrame({'epochs':epoch_list,'lr_rate':learn_list,'val_loss':list(self.history.history['val_loss'])})
       self.df = pd.concat([self.df,lr_df])
       self.loss_record[x] = self.history.history['val_loss']
-      K.clear_session()
+      
 
   def on_train_end(self,logs):
     
